Examples
====================

.. note::

    You are able to install all of the requirements needed to run the example notebooks with:
    `pip install datarobot[examples]`.

.. toctree::
   :maxdepth: 2

   airline_ontime_example/Modeling_Airline_Delay.ipynb
   financial_data/index.rst
   advanced_model_insights/Advanced_Model_Insights.ipynb
   advanced_tuning/Advanced_Tuning_Parameters.ipynb
